# lambdata-dustinstringer
A collection of datascience utility functions.

## Installation:
    pip install lambdata-dustinstringer
  
## Usage:
    from dustydata import ds_utils
> ds_utils is where the utility functions are held.
